@@ -1,4 +1,4 @@
-# Copyright © 2015-2016 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2015-2018 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -86,14 +86,14 @@ class RedundantLength(Error):
 
 # --------------------------------------------------------------------------
 
-class VariableWidth(object):
+class VariableWidth():
 
     type = 'int'
 
     def __init__(self, parent):
         self.parent = parent
 
-class VariablePrecision(object):
+class VariablePrecision():
 
     type = 'int'
 
@@ -102,7 +102,7 @@ class VariablePrecision(object):
 
 # --------------------------------------------------------------------------
 
-class FormatString(object):
+class FormatString():
 
     def __init__(self, s):
         self._items = items = []
@@ -153,7 +153,7 @@ class FormatString(object):
                 j, ch = next_si()
             else:
                 width = 0
-                while ch >= '0' and ch <= '9':
+                while '0' <= ch <= '9':
                     width *= 10
                     width += int(ch)
                     j, ch = next_si()
@@ -166,7 +166,7 @@ class FormatString(object):
                     j, ch = next_si()
                 else:
                     prec = 0
-                    while ch >= '0' and ch <= '9':
+                    while '0' <= ch <= '9':
                         prec *= 10
                         prec += int(ch)
                         j, ch = next_si()
@@ -233,7 +233,7 @@ class FormatString(object):
 
 # --------------------------------------------------------------------------
 
-class Conversion(object):
+class Conversion():
 
     def __init__(self, parent, s, *, key, flags, width, var_width, prec, var_prec, length, conv):
         assert s[-1] == conv, '{0} != {1}'.format(s[-1], conv)
@@ -260,11 +260,10 @@ class Conversion(object):
             except IndexError:
                 raise ArgumentIndexingMixture(s)
             width = ...
-        else:
-            if width > SSIZE_MAX:
-                # The limit is INT_MAX in Python 2.X and SSIZE_MAX in Python 3.X;
-                # but INT_MAX == SSIZE_MAX on mainstream 32-bit architectures.
-                raise WidthRangeError(s, width)
+        elif width > SSIZE_MAX:
+            # The limit is INT_MAX in Python 2.X and SSIZE_MAX in Python 3.X;
+            # but INT_MAX == SSIZE_MAX on mainstream 32-bit architectures.
+            raise WidthRangeError(s, width)
         if var_prec:
             assert prec is None
             try:
