@@ -1,4 +1,4 @@
-# Copyright © 2012-2016 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2020 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -625,7 +625,7 @@ class test_plural_forms:
             (n0, expr0) = M.parse_plural_forms(s)
             del expr0
             assert_equal(n0, n)
-        (n1, expr1, ljunk1, rjunk1) = M.parse_plural_forms(s, strict=False)
+        (n1, expr1, ljunk1, rjunk1) = M.parse_plural_forms(s, strict=False)  # pylint: disable=unbalanced-tuple-unpacking
         del expr1
         assert_equal(n1, n)
         assert_equal(ljunk1, ljunk)
