@@ -1,4 +1,4 @@
-# Copyright © 2012-2016 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2019 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -21,11 +21,15 @@
 import ast
 import importlib
 import inspect
+import operator
 import pkgutil
 
 from nose.tools import (
     assert_equal,
+    assert_false,
     assert_is_instance,
+    assert_raises,
+    assert_true,
 )
 
 import lib.check
@@ -98,4 +102,45 @@ def test_consistency():
     for tag in sorted(source_tagnames | tagnames):
         yield test, tag
 
+class test_enums:
+
+    def t(self, group, *keys):
+        keys = [group[k] for k in keys]
+        operators = (
+            operator.lt,
+            operator.le,
+            operator.eq,
+            operator.ge,
+            operator.gt,
+            operator.ne,
+        )
+        for op in operators:
+            for i, x in enumerate(keys):
+                for j, y in enumerate(keys):
+                    assert_equal(op(x, y), op(i, j))
+                    if op is operator.eq:
+                        assert_false(op(x, j))
+                    elif op is operator.ne:
+                        assert_true(op(x, j))
+                    else:
+                        with assert_raises(TypeError):
+                            op(x, j)
+
+    def test_severities(self):
+        self.t(M.severities,
+            'pedantic',
+            'wishlist',
+            'minor',
+            'normal',
+            'important',
+            'serious',
+        )
+
+    def test_certainties(self):
+        self.t(M.certainties,
+            'wild-guess',
+            'possible',
+            'certain',
+        )
+
 # vim:ts=4 sts=4 sw=4 et
